==> swim-runtime-3.9.3-sources.jar: swim/runtime/lane/SpatialLaneUplink.java <==
// Copyright 2015-2019 SWIM.AI inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package swim.runtime.lane;

import java.util.Iterator;
import java.util.Map;
import swim.concurrent.Stage;
import swim.runtime.LinkBinding;
import swim.runtime.uplink.PartialUplinkModem;
import swim.structure.Attr;
import swim.structure.Record;
import swim.structure.Value;
import swim.warp.SyncRequest;

public class SpatialLaneUplink<S> extends PartialUplinkModem {
  final SpatialLaneModel<S> laneBinding;

  public SpatialLaneUplink(SpatialLaneModel<S> laneBinding, LinkBinding linkBinding) {
    super(linkBinding);
    this.laneBinding = laneBinding;
  }

  @Override
  public SpatialLaneModel<S> laneBinding() {
    return this.laneBinding;
  }

  @Override
  public Stage stage() {
    return this.laneBinding.stage();
  }

  @Override
  protected Value nextDownKey(Value key) {
    final Value value = this.laneBinding.get(key);
    if (value != null) {
      return Attr.of("update", Record.create(1).slot("key", key)).concat(value);
    } else {
      return null;
    }
  }

  @SuppressWarnings("unchecked")
  @Override
  protected void willSync(SyncRequest request) {
    syncDown((Iterator<Map.Entry<Value, Value>>) (Iterator<?>) this.laneBinding.iterator());
    super.willSync(request);
  }
}

==> swim-runtime-3.10.0-sources.jar: swim/runtime/lane/SpatialLaneUplink.java <==
// Copyright 2015-2019 SWIM.AI inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package swim.runtime.lane;

import java.util.Iterator;
import java.util.Map;
import swim.concurrent.Stage;
import swim.runtime.WarpBinding;
import swim.runtime.warp.PartialUplinkModem;
import swim.structure.Attr;
import swim.structure.Record;
import swim.structure.Value;
import swim.warp.SyncRequest;

public class SpatialLaneUplink<S> extends PartialUplinkModem {
  final SpatialLaneModel<S> laneBinding;

  public SpatialLaneUplink(SpatialLaneModel<S> laneBinding, WarpBinding linkBinding) {
    super(linkBinding);
    this.laneBinding = laneBinding;
  }

  @Override
  public SpatialLaneModel<S> laneBinding() {
    return this.laneBinding;
  }

  @Override
  public Stage stage() {
    return this.laneBinding.stage();
  }

  @Override
  protected Value nextDownKey(Value key) {
    final Value value = this.laneBinding.get(key);
    if (value != null) {
      return Attr.of("update", Record.create(1).slot("key", key)).concat(value);
    } else {
      return null;
    }
  }

  @SuppressWarnings("unchecked")
  @Override
  protected void willSync(SyncRequest request) {
    syncDown((Iterator<Map.Entry<Value, Value>>) (Iterator<?>) this.laneBinding.iterator());
    super.willSync(request);
  }
}
